@@ -33,8 +33,8 @@ from lino.utils.xmlgen import html as xghtml
 from lino.utils import AttrDict
 from north import Site
 
-#~ execfile(os.path.join(os.path.dirname(__file__),'setup_info.py'))
-execfile(os.path.join(os.path.dirname(__file__),'..','setup_info.py'))
+execfile(os.path.join(os.path.dirname(__file__),'setup_info.py'))
+#~ execfile(os.path.join(os.path.dirname(__file__),'..','setup_info.py'))
 __version__ = SETUP_INFO['version'] # 
 
 #~ __author__ = "Luc Saffre <luc.saffre@gmx.net>"
