@@ -483,16 +483,18 @@ Django creates copies of them when inheriting models.
         #~ return _(bc)
         
     @classmethod
-    def get_by_name(self,name):
+    def get_by_name(self,name,*args):
+        """
+        Accepts the case that `name` is `None` (returns None then).
+        """
+        #~ return getattr(self,name,*args)
         if name:
-            #~ return getattr(self,name,None)
-            return getattr(self,name)
+            return getattr(self,name,*args)
         else:
-            #~ return self.blank_item
             return None
             
     @classmethod
-    def get_by_value(self,value):
+    def get_by_value(self,value,*args):
         """
         Return the item (a :class:`Choice` instance) 
         corresponding to the specified `value`.
@@ -502,7 +504,7 @@ Django creates copies of them when inheriting models.
         #~ print "get_text_for_value"
         #~ return self.items_dict.get(value,None)
         #~ return self.items_dict.get(value)
-        return self.items_dict[value]
+        return self.items_dict.get(value,*args)
       
     #~ @classmethod
     #~ def items(self):
