@@ -218,7 +218,7 @@ class Menu(MenuItem):
         """
         """
         if isinstance(spec,basestring):
-            spec = settings.LINO.modules.resolve(spec)
+            spec = settings.SITE.modules.resolve(spec)
             #~ if a is None:
                 #~ raise Exception("Could not resolve action specifier %r" % spec)
         if isinstance(spec,actors.BoundAction):
@@ -236,6 +236,9 @@ class Menu(MenuItem):
                 #~ print 20121210, a
             else:
                 a = spec.default_action
+                if a is None:
+                    raise Exception("%r default_action is None?!" % spec)
+                
             #~ a = actors.BoundAction(spec,a)
 
         else:
