@@ -46,10 +46,11 @@ Extended Fields:
 
 Multilingual database content:
 
-- :class:`BabelNamed <north.babel.BabelNamed>`
-- :class:`BabelCharField <north.babel.BabelCharField>`
+- :class:`BabelNamed <north.dbutils.BabelNamed>`
+- :class:`BabelCharField <north.dbutils.BabelCharField>`
 - :class:`BabelTextField <fields.BabelTextField>`
-- :class:`LanguageField <north.babel.LanguageField>`
+- :class:`LanguageField <north.dbutils.LanguageField>`
+- :class:`babelkw <north.dbutils.babelkw>`
 
 Virtual Fields:
 
@@ -192,8 +193,12 @@ from lino.core.fields import Constant, constant
 from lino.core.fields import ForeignKey
 from lino.core.fields import BabelTextField
 
-from north.babel import BabelCharField, BabelNamed, LanguageField
-#~ from north.babel import BabelCharField, BabelTextField, BabelNamed, LanguageField
+from north.dbutils import BabelCharField, BabelNamed, LanguageField
+from north.dbutils import babelkw
+from north.dbutils import babel_values # alias for babelkw for backward compat
+from north.dbutils import set_language
+from north.dbutils import dtos, dtosl
+#~ from north.dbutils import BabelCharField, BabelTextField, BabelNamed, LanguageField
 #~ from lino.core.fields import MethodField
 
 from lino.utils.choosers import chooser
