@@ -27,12 +27,12 @@ from djangosite.utils.test import TestCase
 #from lino.igen import models
 #from lino.modlib.contacts.models import Contact, Companies
 #from lino.modlib.countries.models import Country
-from north import babel
+from north import dbutils
 
 from lino import dd
 Person = dd.resolve_model("contacts.Person")
 from lino.utils.instantiator import Instantiator, create_and_get
-from north.babel import babel_values
+from north.dbutils import babelkw
 
 from lino import mixins
 Genders = mixins.Genders
@@ -52,7 +52,7 @@ def test01(self):
     Tests some basic funtionality.
     """
     ee = create_and_get('countries.Country',
-        isocode='EE',**babel_values('name',
+        isocode='EE',**babelkw('name',
         de="Estland",
         fr='Estonie',
         en="Estonia",
@@ -60,7 +60,7 @@ def test01(self):
         et='Eesti',
         ))
     be = create_and_get('countries.Country',
-        isocode='BE',**babel_values('name',
+        isocode='BE',**babelkw('name',
         de="Belgien",
         fr='Belgique',
         en="Belgium",
@@ -88,8 +88,9 @@ def test01(self):
     and not properly reset.
     """
     
-    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
-        babel.set_language('en')
+    #~ if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('en'):
+        dbutils.set_language('en')
         self.assertEquals(luc.address(), u'''\
 Mr Luc SAFFRE
 Uus 1
@@ -97,15 +98,15 @@ Vana-Vigala küla
 78003 Vigala
 Estonia''')
 
-    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
-        babel.set_language('de')
+    if settings.SITE.get_language_info('de'):
+        dbutils.set_language('de')
         self.assertEquals(luc.address(), u'''\
 Herrn Luc SAFFRE
 Uus 1
 Vana-Vigala küla
 78003 Vigala
 Estland''')
-    babel.set_language(None)
+    dbutils.set_language(None)
     
     
         
@@ -136,7 +137,7 @@ def test02(self):
     luc = Person.objects.get(name__exact="Saffre Luc")
     url = settings.SITE.build_admin_url('api','contacts','Person','%d?query=&an=detail&fmt=json' % luc.pk)
     #~ url = '/api/contacts/Person/%d?query=&an=detail&fmt=json' % luc.pk
-    if 'en' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('en'):
         u.language = 'en'
         u.save()
         response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='en')
@@ -144,7 +145,7 @@ def test02(self):
         self.assertEqual(result['data']['country'],"Estonia")
         self.assertEqual(result['data']['gender'],"Male")
     
-    if 'de' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('de'):
         u.language = 'de'
         u.save()
         response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='de')
@@ -159,7 +160,7 @@ def test02(self):
         self.assertEqual(df['id'],True)
         
         
-    if 'fr' in settings.SITE.AVAILABLE_LANGUAGES:
+    if settings.SITE.get_language_info('fr'):
         u.language = 'fr'
         u.save()
         response = self.client.get(url,REMOTE_USER='root',HTTP_ACCEPT_LANGUAGE='fr')
