@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2010-2011 Luc Saffre
+## Copyright 2010-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -11,11 +11,17 @@
 ## GNU General Public License for more details.
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
+"""
+Note: this fixture supposes that :mod:`few_cities` has also been loaded 
+and thus does not load the few Belgian cities defined there.
+"""
 
-from lino.tools import resolve_model
+from lino.core.dbutils import resolve_model
 from lino.utils.instantiator import Instantiator
+from lino import dd
 
-# copied from http://www.charline.be/info/codepost/cpost.htm
+# The following string is originally copied from
+# http://www.charline.be/info/codepost/cpost.htm
 
 belgian_cities = u"""
 9420 Aaigem 
@@ -62,14 +68,14 @@ belgian_cities = u"""
 1070 Anderlecht 
 6150 Anderlues 
 4821 Andrimont 
-4031 Angleur 
+# 4031 Angleur 
 7387 Angre 
 7387 Angreau 
 5537 Anhée 
 6721 Anlier 
 6890 Anloy 
 5537 Annevoie-Rouillon 
-4430 Ans 
+# 4430 Ans 
 5500 Anseremme 
 7750 Anseroeul 
 5520 Anthée 
@@ -292,7 +298,7 @@ belgian_cities = u"""
 7040 Blaregnies 
 7321 Blaton 
 7370 Blaugies 
-4670 Blégny 
+# 4670 Blégny 
 7620 Bléharies 
 4280 Blehen 
 6760 Bleid 
@@ -417,7 +423,7 @@ belgian_cities = u"""
 1080 Brussel 8 
 1090 Brussel 9 
 3800 Brustem 
-1000 Bruxelles 1 
+# 1000 Bruxelles 1 
 1120 Bruxelles 12 
 1130 Bruxelles 13 
 1140 Bruxelles 14 
@@ -444,17 +450,17 @@ belgian_cities = u"""
 5580 Buissonville 
 1501 Buizingen 
 1910 Buken 
-4760 Bullange 
-4760 Büllingen 
+# 4760 Bullange 
+# 4760 Büllingen 
 8630 Bulskamp 
 3380 Bunsbeek 
 2070 Burcht 
-4210 Burdinne 
+# 4210 Burdinne 
 6927 Bure 
-4790 Burg-Reuland 
+# 4790 Burg-Reuland 
 9420 Burst 
 7602 Bury 
-4750 Bütgenbach 
+# 4750 Bütgenbach 
 3891 Buvingen 
 7133 Buvrinnes 
 6743 Buzenol 
@@ -472,7 +478,7 @@ belgian_cities = u"""
 4317 Celles (Lg.) 
 5561 Celles (Nam.) 
 4632 Cerexhe-Heuseux 
-5630 Cerfontaine 
+# 5630 Cerfontaine 
 1341 Céroux-Mousty 
 7063 Ch.-Notre-Dame-Louvignies 
 4650 Chaineux 
@@ -549,7 +555,7 @@ belgian_cities = u"""
 7120 Croix-lez-Rouveroy 
 4784 Crombach 
 5332 Crupet 
-7033 Cuesmes 
+# 7033 Cuesmes 
 6880 Cugnon 
 5660 Cul-des-Sarts 
 5562 Custinne 
@@ -725,7 +731,7 @@ belgian_cities = u"""
 1040 Etterbeek 
 7340 Eugies (Colfontaine) 
 7080 Eugies (Frameries) 
-4700 Eupen 
+# 4700 Eupen 
 4631 Evegnée 
 5350 Evelette 
 9660 Everbeek 
@@ -1256,7 +1262,7 @@ belgian_cities = u"""
 3950 Kaulille 
 3140 Keerbergen 
 8600 Keiem 
-4720 Kelmis 
+# 4720 Kelmis 
 4367 Kemexhe 
 8956 Kemmel 
 9190 Kemzeke 
@@ -1271,7 +1277,7 @@ belgian_cities = u"""
 3010 Kessel-Lo 
 3640 Kessenich 
 1755 Kester 
-4701 Kettenis 
+# 4701 Kettenis 
 5060 Keumiée 
 9130 Kieldrecht (Beveren) 
 3640 Kinrooi 
@@ -1321,13 +1327,13 @@ belgian_cities = u"""
 3945 Kwaadmechelen 
 9690 Kwaremont 
 7080 La Bouverie 
-4720 La Calamine 
+# 4720 La Calamine 
 7611 La Glanerie 
 4987 La Gleize 
 7170 La Hestre 
 1310 La Hulpe 
 7100 La Louvière 
-4910 La Reid 
+# 4910 La Reid
 6980 La Roche-en-Ardenne 
 3400 Laar 
 9270 Laarne 
@@ -1428,8 +1434,8 @@ belgian_cities = u"""
 8810 Lichtervelde 
 1770 Liedekerke 
 9400 Lieferinge 
-4000 Liège 1
-4020 Liège 2 
+# 4000 Liège 1
+# 4020 Liège 2 
 2500 Lier 
 9570 Lierde 
 4990 Lierneux 
@@ -1503,7 +1509,6 @@ belgian_cities = u"""
 3560 Lummen 
 5170 Lustin 
 6238 Luttre 
-L1217 LUXEMBOURG (BEGGEN) 
 9680 Maarkedal 
 9680 Maarke-Kerkem 
 3680 Maaseik 
@@ -1679,7 +1684,7 @@ L1217 LUXEMBOURG (BEGGEN)
 5555 Monceau-en-Ardenne 
 6592 Monceau-Imbrechies 
 6031 Monceau-sur-Sambre 
-7000 Mons 
+# 7000 Mons 
 4400 Mons-lez-Liège 
 1400 Monstreux 
 6661 Mont (Lux.) 
@@ -1877,7 +1882,7 @@ L1217 LUXEMBOURG (BEGGEN)
 9041 Oostakker 
 8670 Oostduinkerke 
 9968 Oosteeklo 
-8400 Oostende 
+# 8400 Oostende 
 9860 Oosterzele 
 3945 Oostham 
 8020 Oostkamp 
@@ -1925,7 +1930,7 @@ L1217 LUXEMBOURG (BEGGEN)
 4360 Otrange 
 3040 Ottenburg 
 9420 Ottergem 
-1340 Ottignies 
+# 1340 Ottignies 
 9200 Oudegem 
 8600 Oudekapelle 
 9700 Oudenaarde 
@@ -2044,7 +2049,7 @@ L1217 LUXEMBOURG (BEGGEN)
 7380 Quiévrain 
 6792 Rachecourt 
 4287 Racour 
-4730 Raeren 
+# 4730 Raeren 
 6532 Ragnies 
 4987 Rahier 
 7971 Ramegnies 
@@ -2084,7 +2089,7 @@ L1217 LUXEMBOURG (BEGGEN)
 6927 Resteigne 
 2470 Retie 
 4621 Retinne 
-4790 Reuland 
+# 4790 Reuland 
 6210 Rèves 
 5080 Rhisnes 
 1640 Rhode-Saint-Genèse 
@@ -2203,13 +2208,13 @@ L1217 LUXEMBOURG (BEGGEN)
 7030 Saint-Symphorien 
 7100 Saint-Vaast 
 6730 Saint-Vincent 
-4780 Saint-Vith 
+# 4780 Saint-Vith 
 4671 Saive 
 6460 Salles 
 5600 Samart 
 5060 Sambreville 
 6982 Samrée 
-4780 Sankt Vith 
+# 4780 Sankt Vith 
 7080 Sars-la-Bruyère 
 6542 Sars-la-Buissière 
 5330 Sart-Bernard 
@@ -2441,7 +2446,7 @@ L1217 LUXEMBOURG (BEGGEN)
 6717 Thiaumont 
 7070 Thieu 
 7901 Thieulain 
-7061 Thieusies 
+#7061 Thieusies 
 6230 Thiméon 
 4890 Thimister 
 4890 Thimister-Clermont 
@@ -2877,10 +2882,16 @@ fr = u"""
 """
 
 def objects():
-    city = Instantiator("countries.City","zip_code name",country='BE').build
+    countries = dd.resolve_app('countries')
+    city = Instantiator(countries.City,"zip_code name",
+        country='BE',
+        type=countries.CityTypes.city).build
     for ln in belgian_cities.splitlines():
-        if ln.strip():
+        ln = ln.strip()
+        if ln and ln[0] != '#':
             args = ln.split(None,1)
             o = city(*args)
             # print "%r %r" % (o.zip_code, o.name)
             yield o
+            #~ print __name__, "20121114"
+            #~ return 
\ No newline at end of file
