@@ -19,7 +19,7 @@ from django.utils.translation import ugettext as _
 from django.contrib.contenttypes.models import ContentType
 
 from lino.utils.instantiator import Instantiator
-from north.babel import babel_values
+from north.dbutils import babel_values
 from lino.core.dbutils import resolve_model,UnresolvedModel
 
 
