@@ -115,10 +115,8 @@ lino.projects.babel_tutorial.fixtures
 """.splitlines() if n]
   
 SETUP_INFO = dict(name = 'lino',
-  version = '1.6.2',
-  install_requires = ['North==0.0.4','appy',
-    'python_dateutil','PyYAML','odfpy','jinja2',
-    ],
+  version = '1.6.3',
+  install_requires = ['North==0.1.0','appy','PyYAML','odfpy','jinja2'],
   description = "A framework for writing desktop-like web applications using Django and ExtJS",
   long_description = """\
 Lino is a high-level framework for writing desktop-like web applications
@@ -136,7 +134,7 @@ Lino consists of different parts:
   
 - `django-north <https://code.google.com/p/django-north/>`__
   (split off from main project in March 2013)
-  provides python dumps, babel fields and data migration.
+  provides python dumps, multilingual database content and data migration.
 
 - A collection of reusable Django apps and 
   out-of-the-box demo applications
