@@ -48,7 +48,7 @@ from . import views
 #~ import .views
 from lino.core.dbutils import is_devserver
 
-from pkg_resources import Requirement, resource_filename
+from pkg_resources import Requirement, resource_filename, DistributionNotFound
 
 def get_media_urls():
     #~ print "20121110 get_urls"
@@ -84,9 +84,10 @@ def get_media_urls():
         else:
             symlink = getattr(os,'symlink',None)
             if symlink is None:
-                raise Exception("Cannot run a production server on an OS that doesn't have symlinks")
+                logger.info("Cannot create symlink %s -> %s.",target,source)
+                #~ raise Exception("Cannot run a production server on an OS that doesn't have symlinks")
             else:
-                logger.info("Setting up symlink %s -> %s.",target,source)
+                #~ logger.info("Setting up symlink %s -> %s.",target,source)
                 symlink(source,target)
         
     if not settings.SITE.extjs_base_url:
@@ -105,9 +106,12 @@ def get_media_urls():
     if settings.SITE.use_eid_jslib:
         setup_media_link('eid-jslib','eid_jslib_root')
         
-    #~ setup_media_link('lino',source=join(dirname(lino.__file__),'media'))
     #~ setup_media_link('lino',source=join(dirname(lino.__file__),'..','media'))
-    setup_media_link('lino',source=resource_filename(Requirement.parse("lino"),"media"))
+    try:
+        setup_media_link('lino',source=resource_filename(Requirement.parse("lino"),"lino/media"))
+    except DistributionNotFound as e:
+        # if it is not installed using pip, link directly to the source tree
+        setup_media_link('lino',source=join(dirname(lino.__file__),'media'))
     
     
 
@@ -154,6 +158,8 @@ def get_plain_urls():
 
 def get_ext_urls():
     #~ print "20121110 get_urls"
+    settings.SITE.ui.ext_renderer.build_site_cache()
+    
     rx = '^'
     urlpatterns = patterns('',
         (rx+'$', views.AdminIndex.as_view()),
