@@ -69,7 +69,6 @@ from lino.core import tables
 #~ from lino.core.dbutils import full_model_name
     
 from lino.utils import choosers
-from north import babel
 from lino.core import choicelists
 from lino.core import menus
 from lino.utils import jsgen
@@ -751,6 +750,7 @@ tinymce.init({
             return
         
         started = time.time()
+        #~ logger.info("build_site_cache started")
         
         settings.SITE.on_each_app('setup_site_cache',force)
         
@@ -759,17 +759,17 @@ tinymce.init({
         
         if force or settings.SITE.build_js_cache_on_startup:
             count = 0
-            langs = settings.SITE.AVAILABLE_LANGUAGES
-            for lang in langs:
-                babel.set_language(lang)
+            #~ langs = settings.SITE.AVAILABLE_LANGUAGES
+            for lng in settings.SITE.languages:
+                dd.set_language(lng.django_code)
                 for profile in dd.UserProfiles.objects():
                     count += self.build_js_cache_for_profile(profile,force)
             #~ qs = users.User.objects.exclude(profile='')
             #~ for lang in langs:
-                #~ babel.set_language(lang)
+                #~ dd.set_language(lang)
                 #~ for user in qs:
                     #~ count += self.build_js_cache_for_user(user,force)
-            babel.set_language(None)
+            dd.set_language(None)
                 
             logger.info("%d lino*.js files have been built in %s seconds.",
                 count,time.time()-started)
